package Org::Export::Text;

use 5.010001;

our $VERSION = '0.02'; # VERSION

1;
# ABSTRACT: Export Org document to text

__END__

=pod

=encoding UTF-8

=head1 NAME

Org::Export::Text - Export Org document to text

=head1 VERSION

This document describes version 0.02 of Org::Export::Text (from Perl distribution Org-To-Text), released on 2015-08-18.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Org-To-Text>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Org-To-Text>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Org-To-Text>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
